# actually, the date is the date packaged, not the commit date
%global commit_date	20200813
%global commit_long	f73fca015d421b763936667a0b58fe5024d59921
%global commit_short	%(c=%{commit_long}; echo ${c:0:7})

Name:		raspberrypi-vc
Version:	%{commit_date}
Release:	506.git%{commit_short}%{dist}

Summary:	VideoCore GPU libraries, utilities, and demos for Raspberry Pi

License:	Redistributable, with restrictions; see LICENSE.broadcom
URL:		https://github.com/raspberrypi
Source0:	https://github.com/raspberrypi/userland/archive/%{commit_long}.tar.gz

# Patch0 fixes up paths for relocation from /opt to system directories.
Patch0:		raspberrypi-vc-demo-source-path-fixup.patch

# dtoverlay
BuildRequires:	libfdt-devel >= 1.4.1-501.gitbeef80b%{?dist}
Requires:	libfdt >= 1.4.1-501.gitbeef80b%{?dist}

BuildRequires:	cmake, gcc-c++

ExclusiveArch:	%{arm} aarch64

%description
Libraries, utilities and demos for the Raspberry Pi BCM2835/6 SOC GPU


%package libs
Summary:	Libraries for accessing the Raspberry Pi GPU
Requires:	raspberrypi2-firmware

%description libs
Shared libraries for accessing the BCM2835/6 VideoCore GPU 
on the Raspberry Pi computer.


%package libs-devel
Summary:	Headers for libraries that access the Raspberry Pi GPU
Requires:	%{name}-libs = %{version}
License:	GPLv2+ and Freely redistributable, with restrictions; see LICENCE.broadcom and headers

%description libs-devel
Header files for accessing the BCM2835 VideoCore GPU on 
the Raspberry Pi computer.


%package demo-source
Summary:	Demo source for accessing the Raspberry Pi GPU
Requires:	%{name}-libs = %{version}
License:	ASL 2.0
BuildArch:	noarch

%description demo-source
Demo source code for accessing the BCM2835 VideoCore GPU
on the Raspberry Pi computer.


%package utils
Summary:	Utilities related to the Raspberry Pi GPU
Requires:	%{name}-libs = %{version}

%description utils
Utilities for using the BCM2835/6 VideoCore GPU on the 
Raspberry Pi computer.


%package static
Summary:	Static libraries for accessing the Raspberry Pi GPU
Requires:	%{name}-libs = %{version}

%description static
Static versions of libraries for accessing the BCM2835/6 VideoCore GPU
on the Raspberry Pi computer.


%prep
%setup -q -n userland-%{commit_long}

%patch0 -p1
%ifarch aarch64
sed -i 's/__bitwise/FDT_BITWISE/' opensrc/helpers/libfdt/libfdt_env.h
sed -i 's/__force/FDT_FORCE/' opensrc/helpers/libfdt/libfdt_env.h
%endif

%build
mkdir build
pushd build
cmake -DCMAKE_BUILD_TYPE=ReleaseWithDebInfo -DCMAKE_C_FLAGS="%{optflags} -fgnu89-inline" \
%ifarch aarch64
    -DARM64=ON \
%endif
    ..
make %{?_smp_mflags} all

%install
rm -rf %{buildroot}

pushd build 
make install DESTDIR=%{buildroot}

# /opt/vc -> /usr
mkdir -p %{buildroot}/usr
mv %{buildroot}/opt/vc/bin %{buildroot}/usr

mkdir -p %{buildroot}%{_libdir}/vc
mv %{buildroot}/opt/vc/lib/* %{buildroot}%{_libdir}/vc

## pkgconfig files
pushd $RPM_BUILD_ROOT%{_libdir}/vc/pkgconfig
for f in *.pc; do sed -i "/^prefix=.*$/d" $f; done
for f in *.pc; do sed -i "/^exec_prefix=.*$/d" $f; done
for f in *.pc;\
 do sed -i "s|^libdir=.*$|libdir=%{_libdir}/vc|" $f; done
for f in *.pc;\
 do sed -i "s|^includedir=.*$|includedir=%{_includedir}/vc|" $f; done
popd # $RPM_BUILD_ROOT%{_libdir}/vc/pkgconfig

mkdir -p %{buildroot}/usr/include/vc
mv %{buildroot}/opt/vc/include/* %{buildroot}/usr/include/vc

mkdir -p %{buildroot}/%{_datadir}/raspberrypi-vc-demo-source
mv %{buildroot}/opt/vc/src/hello_pi\
 %{buildroot}/%{_datadir}/raspberrypi-vc-demo-source

# cleanup
rm -rf %{buildroot}/etc
rm -rf %{buildroot}/opt

mkdir -p %{buildroot}%{_sysconfdir}/ld.so.conf.d
cat <<__EOF__ >%{buildroot}%{_sysconfdir}/ld.so.conf.d/raspberrypi-vc-libs.conf
%{_libdir}/vc
__EOF__
chmod 644 %{buildroot}%{_sysconfdir}/ld.so.conf.d/raspberrypi-vc-libs.conf

popd # build

%post libs
/sbin/ldconfig

%postun libs
/sbin/ldconfig

%files libs
%defattr(0644,root,root,0755)
%dir %{_libdir}/vc
%attr(0755,-,-) %{_libdir}/vc/libbcm_host.so
%attr(0755,-,-) %{_libdir}/vc/libdebug_sym.so
%attr(0755,-,-) %{_libdir}/vc/libdtovl.so
%attr(0755,-,-) %{_libdir}/vc/libvchiq_arm.so
%attr(0755,-,-) %{_libdir}/vc/libvcos.so
%ifarch %{arm}
%attr(0755,-,-) %{_libdir}/vc/libbrcmEGL.so
%attr(0755,-,-) %{_libdir}/vc/libbrcmGLESv2.so
%attr(0755,-,-) %{_libdir}/vc/libbrcmOpenVG.so
%attr(0755,-,-) %{_libdir}/vc/libbrcmWFC.so
%attr(0755,-,-) %{_libdir}/vc/libEGL.so
%attr(0755,-,-) %{_libdir}/vc/libGLESv2.so
%attr(0755,-,-) %{_libdir}/vc/libOpenVG.so
%attr(0755,-,-) %{_libdir}/vc/libWFC.so
%attr(0755,-,-) %{_libdir}/vc/libcontainers.so
%attr(0755,-,-) %{_libdir}/vc/libmmal.so
%attr(0755,-,-) %{_libdir}/vc/libmmal_components.so
%attr(0755,-,-) %{_libdir}/vc/libmmal_core.so
%attr(0755,-,-) %{_libdir}/vc/libmmal_util.so
%attr(0755,-,-) %{_libdir}/vc/libmmal_vc_client.so
%attr(0755,-,-) %{_libdir}/vc/libopenmaxil.so
%attr(0755,-,-) %{_libdir}/vc/libvcsm.so
%dir %{_libdir}/vc/plugins
%attr(0755,-,-) %{_libdir}/vc/plugins/*.so
%endif
%{_sysconfdir}/ld.so.conf.d/raspberrypi-vc-libs.conf
%doc LICENCE

%files libs-devel
%defattr(0644,root,root,0755)
%{_includedir}/*
%{_libdir}/vc/pkgconfig
%doc LICENCE

%files static
%defattr(0644,root,root,0755)
%dir %{_libdir}/vc
%{_libdir}/vc/*.a
%doc LICENCE

%files utils
%defattr(0644,root,root,0755)
%attr(4755,root,root) %{_bindir}/*
%doc LICENCE

%files demo-source
%defattr(0644,root,root,0755)
%{_datadir}/raspberrypi-vc-demo-source
%doc LICENCE

%changelog
* Sun Sep 27 2020 Pablo Greco <pgreco@centosproject.org> - 20200813-506
- Update to newer version from upstream
- Build for aarch64

* Sat Jun  6 2020 Pablo Greco <pgreco@centosproject.org> - 20200528-505
- Update to newer version from upstream

* Sun Mar 15 2020 Pablo Greco <pgreco@centosproject.org> - 20200315-504
- Update to newer version from upstream

* Wed Feb 27 2019 Pablo Greco <pablo@fliagreco.com.ar> - 20190115-503
- Update to newer version from upstream
- spec cleanup

* Tue Sep 12 2017 Fabian Arrotin <arrfab@centos.org> 
- Changed a Requires: to raspberrypi2-firmware (one used for CentOS 7 userland)

* Wed Jul 05 2017 Clive Messer <clive.messer@squeezecommunity.org> - 20170705-501.gitaa39775
- Git revision master aa3977538b04038628ff5b3a39a8e42ddcbc9176
  vcdbg: Don't use dma when file provided

* Mon Jul 03 2017 Clive Messer <clive.messer@squeezecommunity.org> - 20160922-502.gita1b89e9
- Rebuild for F25

* Thu Sep 22 2016 Clive Messer <clive.messer@squeezecommunity.org> - 20160922-501.gita1b89e9
- Git revision master a1b89e91f393c7134b4cdc36431f863bb3333163
  Updates for vcdbg build
- Git revision master 62519629e523c1fb80f2fe43c29b9654670d49e5
  VCOS Pthreads: assert mod
  Unused variable in release builds otherwise
- Git revision master 1981f5b5976ce0bbfcf9ed87c1b23360fb00c645
  tvservice/cecservice: We only care about unexpected message sizes
- Git revision master 22eb23706085153368aa8413efbc09976ea2798c
  vchiq: Allow inclusion from C++
- Git revision master 19d0403234e30e8344c02f80972501d2d631ca7a
  Remove unused files after #312
- Git revision master 52a2a388878602f1613b69815368d64df9992616
  Advertise sliced formats in MMAL_PARAMETER_SUPPORTED_ENCODINGS
- Git revision master 6fc52d885efc821cc6da3740b640e2829dc7f8c0
  VCHI clients: Poll for messages until empty
- Git revision master 45f58000f8cab03f8fd20efd610c8edc9ed422d8
  vmcs_host: Poll for multiple dispmanx messages
  When VCHI delivers a callback indicating that a message is available,
   there could be more than one waiting. Therefore it is necessary to
   poll until vchi_msg_dequeue fails.
  Without this patch, failure to keep up with vsync messages will cause
   a gradually increasing tailback, eventually leading to a stall because
   the slots aren't being recycled.

* Mon Sep 12 2016 Clive Messer <clive.messer@squeezecommunity.org> - 20160909-502.git43be4cf
- Don't copy dtoverlay-{pre,post} scripts
  Apply raspberrypi-vc-dont-copy-dtoverlay-scripts.patch

* Fri Sep 09 2016 Clive Messer <clive.messer@squeezecommunity.org> - 20160909-501.git43be4cf
- Git revision master 43be4cf6f0e53c4e7051761b113353ea9b51b094
  MMAL: Add support for MMAL_ENCODING_xxx_SLICE formats
- Git revision master dca6090e77835b935c318b9bf166418e258ba37f
  Merge pull request #312 from luked99/fix-compiler-warnings
  Fix compiler warnings
- Git revision master d9ffcca70e730c02059591035bce4439341f4175
  Remove the unused usbdk code
  This code does not get used for anything, and simply generates
   compiler warnings which can't easily (if at all) be fixed. Remove
   it.
- Git revision master b0563f6c1dbb478ae69b5a90bdf14c8c4715753f
  vchiq_arm: Fix return value of vchiq_initialise
- Git revision master 3dae9a6b87e5ef6999c626e977e262944bfe25df
  Merge pull request #332 from jogu/master
  Add name to anonymous structs in RaspiCamControl.h
- Git revision master 1bdb529149950a6176b6767c8f6bf83b0753a1be
  Add name to anonymous structs in RaspiCamControl.h
  This is useful as it allows applications to pass around struct
   raspicam_camera_parameters_s * parameters without the need to include
   RaspiCamControl.h and all it's dependencies.
- Git revision master 016428c6de9c0a5983115a09b874782ab72615db
  Merge pull request #330 from 6by9/master
  Fix for issue #170, and raspividyuv supporting rgb
- Git revision master a141fc75387020a49f77e1e8907d7d1dde32ca16
  RaspiVidYuv: Add option of saving RGB data.
  Copied from RaspiStillYuv.
- Git revision master 87ccdff60a2ba43dc2e44bb7b28877726eda0d17
  Raspi[Still|Vid]Yuv: Add option for just saving luma
  Fixes #170
  Option for saving only the luma / Y plane of the image data.
- Git revision master 7acc9d4f2986a78640fafcf8ce4166fe1baa07f2
  raspistill: Fix framestart off by one error
  See: https://github.com/raspberrypi/userland/issues/320
- Git revision master 3a0a0e858be7dfaa0625a23a9579590e05a035c8
  raspistill: cosmetic: Whitespace cleanup
- Git revision master ca1243e6e1ec6221c406a66960d9b18ddffdd0bc
  mmal: Allow /dev/vchiq to be opened initialised prior to mmal_vc_init
  This avoids an issue with Chromium sandbox

* Thu Jul 28 2016 Clive Messer <clive.messer@squeezecommunity.org> - 20160728-501.gita63658c
- Git revision master a63658c5950ce4ac6dc9d125ed977be91896d68c
  vc_client: Fix for sending vguPolygon data in chunks
   See: https://github.com/raspberrypi/firmware/issues/633
- Git revision master 6c60fb035836723c92efd1bf81e14f2cb4790010
  Update RaspiStill.c (#324)

* Wed Jul 13 2016 Clive Messer <clive.messer@squeezecommunity.org> - 20160713-501.git333cdee
- Git revision master 333cdee2ab1b236a5836c4dc419cfaf22c423ab9
  Raspistill: Add option to set the JPEG restart interval.
  https://www.raspberrypi.org/forums/viewtopic.php?f=38&t=153553
- Git revision master 6afb34372c810500d765fa70d4a28874b73c1f36
  image_encode: Add parameter to set the restart interval.
  Requested on https://www.raspberrypi.org/forums/viewtopic.php?f=38&t=153553
- Git revision master 4171e9765e8b7bbfc84ceeea3af8f5abc742c24e
  deinterlace: Allow interlaced state of video buffer to be signalled from host
- Git revision master 1ef892127bf4c4b5dd3050b03b7cf35c3a2419ea
  wfc: Fix typo in comment

* Tue Jul 05 2016 Clive Messer <clive.messer@squeezecommunity.org> - 20160705-501.git0b8c195
- Git revision master 0b8c195d9fbee2909b3cee8c8e15a903b678e6e0
  arm_dt: Add macros for GETBE4 and SETBE4
- Git revision master dd98890106c3c6145f640c4cfb825be937282a93
  makefile: Switch to building and using GL libs with custom names
- Git revision master 094e9ff522f9f8b82e33ec8684cfa2025b85a9b6
  Revert "cmake: mark GLESv2 as so version 2 for consistency with mesa lib"
  This reverts commit 1180140d23a82a98b905babc2f27e27663cef205.
- Drop raspberrypi-vc-EGL-dep.patch

* Sun Jul 03 2016 Clive Messer <clive.messer@squeezecommunity.org> - 20160703-502.gitdd9636d
- libEGL needs libGbLSv2
  Apply raspberrypi-vc-EGL-dep.patch

* Sun Jul 03 2016 Clive Messer <clive.messer@squeezecommunity.org> - 20160703-501.gitdd9636d
- Git revision master 1180140d23a82a98b905babc2f27e27663cef205
  cmake: mark GLESv2 as so version 2 for consistency with mesa lib
   See: https://github.com/anholt/mesa/issues/24

* Wed Jun 29 2016 Clive Messer <clive.messer@squeezecommunity.org> - 20160629-501.gitdd9636d
- Git revision master dd9636d73eaaf8a9273911e1773b012838fc250c
  MMAL_VC_SHM: Explicitly lock buffer when requested
  Avoids relying on the page fault locking it and
   the potential deadlock in VCHI.
- Git revision master 633f5e6949871daf1917fb70956069d5d29ede02
  vidtex: Remove unused variable
- Git revision master 4364cc3c3138ebf6f6f6422da12c81b9c237c339
  khrn_client_platform_linux: Avoid uninitialised warnings
- Git revision master 6eb22bdfa9d9cd8117fc95526d9ff6d79e411414
  RaspiVid: Fix printf format string
- Git revision master 3590fef64d3922a7d4dabcea4f2d250f2a9eb113
  tvservice: Avoid uninitialised variable warnings
- Git revision master bcaf42302f8819e4202197767692873edaef7df4
  tvservice: Use correct aspect ratio string for sd
- Git revision master b11270b868f0d03ab1f495983a02c9d8ff4cbbab
  vc_service: Avoid implicit cast warning
- Git revision master aeb45a8d8133d132cce74e613b28dc83fcc65391
  message_dispatch: Initialise variable
- Git revision master f835ecbd77303322f057a9fccc068c802b3ba67a
  wfc: service is an integer type
- Git revision master 04c7d1e4104826086131e211c9263377454fdc57
  vc_service_common: Ensure error codes are unique
- Git revision master 3f88c53ddb3ee7ca23e5771e6edb3cbab239f917
  vchiq_lib: Minor fixes
- Git revision master 2932c92f26a8ed5f6ebd43a8feb274837085af47
  vchiq_test: minor fixes
- Git revision master 700dc33f7112fdef957500b84d006460f0fc8e21
  vcos: Use vcos_free for vcos_malloc buffer
- Git revision master 68de46dc8b70c6906ee7f45baa0817af6d0df1e0
  Add --debug and --native options to buildme
- Git revision master c8ed769bc3c2bb8a2f3f36a6b0427e330feba62f
  vcos: Implement vcos_strdup directly
- Git revision master 1cd52053c7f1366f4b5e3300e8c8a5dce2709da4
  khronos: Use vchiq_get_client_id to determine global PID. (#315)
  PID namespacing breaks VCHIQ as it uses PIDs as unique identifiers for VCHIQ
   services, meaning messages sent from userland will contain a different ID than
   the one expected by the GPU.
  This patch addresses the problem uses the existing GET_CLIENT_ID ioctl to
   retrieve the global PID as seen by the kernel rather than using the process's
   reported PID.
- Git revision master 0147f98bdd4fdc822d25d8a70cf5adc5adb89096
  Update raspicam helptext (#322)
  Valid --drc options are mentioned in the Notes (just like the valid options
   for --exposure, --awb, --imxfx and --metering)
- Git revision master c82c6515d4ffdf5301539ccb494def6ca4331f5f
  RaspiStill: Update annotation before capture (#321)

* Mon Jun 27 2016 Clive Messer <clive.messer@squeezecommunity.org> - 20160613-502.git8daf8dd
- Rebuild for F24

* Mon Jun 13 2016 Clive Messer <clive.messer@squeezecommunity.org> - 20160613-501.git8daf8dd
- Git revision master 8daf8dd493ecd25ceda075cd6ffa646193f00edb
  Add option -lev/--level to raspvid to select H264 Level (#318)
  Enable selection of Level 4, 4.1 and 4.2 for H264 codec.
  Level will be automatically increased if necessary.
  Additional preview buffer will be allocated for higher framerates.
- Git revision master 7c026fa7a4ded2c525916cc853a32731c072ed1e
  RaspiStillYuv: Detect and amend request for RGB pixel ordering
  Firmware has been corrected to return the correct pixel ordering
   for RGB24 and BGR24 pixel formats - they were reversed before.
   When in RGB mode, query the supported encodings and choose the
    right one.
   mmal_util function added to make it easy from client apps.
- Git revision master 826b0b1b089329cdd9c3c9a3a91c0ffe915cf248
  Adjust include paths for Linux/BSD
   See: https://github.com/raspberrypi/userland/pull/298
- Git revision master ed59ee1f17d9a4ad86f1c7cdbc6fd86b3978c82a
  dtoverlay: Run scripts before and after changes
- Git revision master 05d60a01d53dca363bb4286594db1826ffff8762
  cmake: generate and install pkgconfig files
  many packages expect packageconfig support especially for detecting EGL
   libraries. This patch helps in compiling those packages on RPi
  Signed-off-by: Khem Raj <raj.khem@gmail.com>
- Git revision master 1eac015380bbc3ef7acf6e8b98cb15968647b4df
  IL Components: Documentation update

* Sun May 08 2016 Clive Messer <clive.messer@squeezecommunity.org> - 20160508-501.git17c28b9
- Git revision master 17c28b9d1d234893b73adeb95efc4959b617fc85
  firmware: vcos: Fix incorrect licence
- Git revision master dff576057c7b6f4936a903406be3c491e26c2c73
  Allow command-line overriding of VMCS_PLUGIN_DIR (#309)
- Git revision master f824ef5530012f83a9ef8a8089eaadf13f6963e9
  raspistill: Use camera_info component to set the sensor name and output
   resolution of the captures. This queries the VC firmware for the camera
   currently attached.
- Git revision master 38f9c7ef46be6d738597fa7c3b22631c98ef125e
  dtoverlay: Require sudo for destructive operations
- Git revision master d023ba6537b21b5137411e0d868dd52648684b70
  dtoverlay: command line tweaks
   dtoverlay -r   # Remove the most recent overlay or dtparam
   dtoverlay -R   # Remove all overlays and dtparams
   dtparam        # List all parameters
   dtparam -h     # Show usage
   dtparam -r     # Remove the most recent dtparam or overlay
   dtparam -R     # Remove all dtparams and overlays

* Tue Apr 19 2016 Clive Messer <clive.messer@squeezecommunity.org> - 20160419-501.git52eca99
- Git revision master 52eca998aa43f278314579dba4798a3fe1da46c3
  vc_image: Remove ifdefs for obsolete platforms
- Git revision master ae68bb115b185c95e8d5f84050c58e6b49f9e491
  dtmerge: Don't crash if the overlay fails to load
- Git revision master 8b5cb841d0cde031e98c5dd2e1151b683f826b38
  dtoverlay: Copy overrides before applying
  dtoverlay: Refactor applying overlays to permit snooping
  dtoverlay: Add dtparam command
  dtoverlay: Integer overrides can create and extend properties

* Sun Apr 17 2016 Clive Messer <clive.messer@squeezecommunity.org> - 20160417-501.git6732ebd
- Git revision master 6732ebd37033a9f533be653665b8b1696cab1f1f
  vcilcs: Warn as message queue approaches fullness
   See: https://github.com/raspberrypi/firmware/issues/449
- Git revision master 01414db13aee69ee4da89178129b98df57cc0cb3
  vcilcs: Increase ILCS queue size to prevent(?) deadlock
   See: https://github.com/raspberrypi/firmware/issues/449
- Git revision master 346195a99cd9e0c97874abad957cbe308de0a589
  dtmerge: Pack the merged DTB before writing
- Git revision master 0fac82c74d0f8250ababeaaac34df3aa29651d80
  dtoverlay: Copy overrides before applying
  Override data can move as the overrides are applied, so copy it before
   application.
- Git revision master 506017f970f38a5e6c1dbf168de9149224530ca4
  Fix unixtime '1900' typo in raspistill --help (#308)

* Sat Apr 16 2016 Clive Messer <clive.messer@squeezecommunity.org> - 20160416-501.gitcfd971c
- Git revision master cfd971c6300b4f2c1929fdd95a09d9bb03b87dbe
  Merge pull request #306 from 6by9/PR20160407
  Raspivid: Add option for MJPEG codec
- Git revision master 4e259dcbecf2ee5898a118916d2236c43f5ef713
  Raspivid: Add option for MJPEG codec
- Git revision master 770f2bd9cc4ae57a682e7b0635bc1214aa082bbe
  Merge pull request #299 from stweil/master
  Fix some typos found by codespell
- Git revision master 6ce5faffba97d96814c31168c9737729f3f9d019
  Merge pull request #136 from ethanol100/fixIf
  Wrong sign in if condition
- Git revision master 8b0a23de21b5910df1d64642f4175f6fc5ee679b
  host_applications: Fix typos in comments
  Most of them were found and fixed using codespell.
  Signed-off-by: Stefan Weil <sw@weilnetz.de>

* Wed Apr 06 2016 Clive Messer <clive.messer@squeezecommunity.org> - 20160406-501.gite0fc99d
- Git revision master e0fc99d48fc7a1019e2c5f80f994108b3fe94ba5
  hello_video: Remove the timout, to avoid the application quits before the ending of some videos
   See: https://github.com/raspberrypi/firmware/pull/475
- Git revision master 68424c00132843950de05b32fa9d3868dbdbc973
  hello_pi: Use absolute path for libs
- Git revision master c236548aa87b64e9b0237839570c5a07d290e64f
  host_applications: Add dtmerge application
  dtmerge allows an overlay to be applied to a specified base DTB, with
   parameters, saving the result as another DTB. This makes it easy to
   test an overlay without the need to reboot.
- Git revision master ffb6c704452cfe89cb91b6d58d44e9020b53cf9b
  dtoverlay: Multiple overlay instances
  Allow dtoverlay to load the same overlay multiple times. Removing an
   overlay by name removes the most recent instance. Removing by index
   (position in the list) works as expected. Use '-R' to remove all overlays
   from a specified index or named overlay. dtoverlay -R 0 will remove all
   overlays.
- Git revision master a52bb288341a6be58744ec9dbb0ea53d14aea4b4
  dtoverlay: Support disabled (__dormant__) fragments
  Fragments where the __overlay__ node is named __dormant__ will
   automatically be ignored. The new 'overlay-level overrides variant,
   indicated by a 0 phandle, allows numbered fragments to be enabled or
   disabled, either absolutely or dependent on the override value.
  Example:
      just_one = <0>,"+1-2";    // Enable 1, disable 2
      conditional = <0>,"=3!4"; // Enable 3, disable 4 if value is true
                                  // otherwise disable 3, enable 4.
- Git revision master 191f9f872042ea58aee61134f5c1e5237972ea35
  dtoverlay: Allow aliases to be used with target-path
  The target-path property normally refers to an absolute path, but
   this commit allows an alias to be used instead, making it possible
   to refer to use:
      target-path = "i2c_arm";
- Git revision master 481fcfbcf812f89c5ab8d0a45a1ab4218ff69380
  Fix some typos found by codespell
   See: https://github.com/raspberrypi/userland/pull/299

* Fri Apr 01 2016 Clive Messer <clive.messer@squeezecommunity.org> - 20160401-501.git703a2c4
- Git revision master 703a2c4b35e23ee44ad84db6b9c3f89c0a627143
  dtoverlay: Compile libfdt into libdtovl
  Compile the static library libfdt into libdtovl, rather than deferring
   its linking to clients of libdtovl.

* Wed Mar 30 2016 Clive Messer <clive.messer@squeezecommunity.org> - 20160330-502.git33f6e66
- Git revision master 33f6e668bc0c87fd5ea36bf5e682009b938580f4
  dtoverlay: Actually use the result of fread...
  ...because void casts are no longer sufficient on return values marked
   with attribute warn_unused_result.
  See: https://github.com/raspberrypi/userland/pull/300
       https://github.com/raspberrypi/userland/issues/302

* Wed Mar 30 2016 Clive Messer <clive.messer@squeezecommunity.org> - 20160330-501.git964deab
- Git revision master 964deab3d76fde168a204cc17c6b463d3b3f801f
  dtoverlay: Fixing numerous compiler nit-picks
  See: https://github.com/raspberrypi/userland/pull/300
       https://github.com/raspberrypi/userland/pull/301
       https://github.com/raspberrypi/userland/issues/302
- Git revision master e8de525fa47ce36d2c120e2614f5848d1e7b3803
  vchiq_lib: Don't overwrite loop count mid-loop
- Drop rpi-vc-CMakeLists-dtoverlay.patch

* Sat Mar 19 2016 Clive Messer <clive.messer@squeezecommunity.org> - 20160319-501.git2f56a29
- Git revision master 2f56a2943a9eb8420df52ccf91f5a1c5a70e8713
  MMAL Examples: Some fixups for the Pi tree
- Git revision master 930ecc100b4f2bea8530c07abe3b9ca3959b369c
  dtoverlay: Add makefile updates

* Tue Mar 15 2016 Clive Messer <clive.messer@squeezecommunity.org> - 20160315-501.gite93c382
- Build dtoverlay
  Apply rpi-vc-CMakeLists-dtoverlay.patch
- Git revision master e93c382c4e70d43c1b010f035c0f2a13697737ae
  dtoverlay: Add source for libs
- Git revision master 84c6c4c0d3936bb13b204bee48781c99edcec6f9
  dtoverlay: Add source for dtoverlay utility

* Tue Mar 08 2016 Clive Messer <clive.messer@squeezecommunity.org> - 20160308-501.git8369e39
- Git revision master 8369e390999f4a7c3bc57e577247e0dd502c51f7
  Merge pull request #297 from kfitzgerald/raspiyuv-flush
  raspiyuv: Flush stdout to ensure image is fully sent
- Git revision master 96ebe93f8b8aa47ada72e8481bf9d1cf6cb1f344
  Flush stdout to ensure image is fully sent
  Flush stdout when dumping image data over stdout. Without the flush, using
   signals to stream image data over stdout would result in the missing data,
   if the buffer didn't fill the 65536 chunk.

* Mon Feb 29 2016 Clive Messer <clive.messer@squeezecommunity.org> - 20160229-501.git748b2ba
- Git revision master 748b2ba6112435063352d72f48d1d6dcc124bd6f
  OpenMax IL: Add warning if OMX_SKIP64BIT is not defined
  struct OMX_BUFFERHEADERTYPE does not align a 64bit value
   (nTimestamp) to a 64bit boundary. Metaware is fine with this.
  Most ARM compilers will add in padding, and then you don't
   have the same result.
  ARM side can be made to work by adding OMX_SKIP64BIT.
- Git revision master 6bdc6fef56b4332f16dc4175e13ab3560f7d237b
  cmake: define PROJECT_APIVER
  this helps in compiling components which use packageconfig to poke for
   library versions and requiring minimum supported version
  Signed-off-by: Khem Raj <raj.khem@gmail.com>
- Git revision master 9a1a28e7778f857e695cd5dcc6c61702820ba3ec
  MMAL Examples: Some fixups for the Pi tree
- Git revision master cecb2f6a549d9292436f827a90397db9c25c317e
  Fix some compiler warnings
   See: https://github.com/raspberrypi/userland/pull/290
- Git revision master 0922eb8e9af73d459ecd871a866134976f69e5b0
  hello_triangle: Free all resources on exit
- Git revision master 17e947740aaf075ea1515705a03e304b1b427d03
  Fix typos in various headers
- Git revision master e5afa6210e03aa8fd6bff74defd9d397340f2926
  mmal: Fix warnings due to error types
   See: https://github.com/raspberrypi/userland/pull/290
- Git revision master dbd8c26735c99cb6ebc50ba915521dbcc192d943
  mmal: Remove unwanted loop increment from body of code
   See: https://github.com/raspberrypi/userland/pull/292
- Git revision master 2a4af2192c0e161555fdb2a12e902b587166c4a6
  Merge pull request #287 from jasaw/fix_warnings
  RaspiStill: Fix compiler warnings

* Mon Feb 01 2016 Clive Messer <clive.messer@squeezecommunity.org> - 20160201-501.git0863709
- Git revision master 0863709b9fb90ee1204b7fe52f69535830d3c111
  Update copyright
- Git revision master 190bf8cb4b281ff43c4f9dc06bc26494329d5742
  cmake: Add -marm for building with generic toolchain
- Git revision master f799ee0ba274464af09d385af3b32b0377198fa9
  Fix typos in various headers
   See: https://github.com/raspberrypi/firmware/pull/518

* Fri Jan 29 2016 Clive Messer <clive.messer@squeezecommunity.org> - 20160129-501.git10e49b3
- Git revision master 10e49b3759e852f6b2cb1c6aff2e129d77d01933
  Merge pull request #282 from 6by9/PR20160114
  Add a flag to raspistill to start the frame number on something other…
- Git revision master 23824598443348c0bc9634b90310ec2029519879
  Add a flag to raspistill to start the frame number on something other than 0.
  This allows restarting raspistill without overwriting existing images.
- Git revision master 35e4a8353b26412ca3bc6b258ce438a80a56d434
  Merge pull request #280 from TheSin-/master
  GCC5 fixes
- Git revision master 7340e8f020faf31a3bab8b6e90b9feaa55af2531
  Fix for format security errors in gcc5
- Git revision master 352575718df7097dae5f938c55a4ca9a62baf603
  Fix a maybe uninitialized warning in gcc5
- Git revision master aa66cccc9a84f6270d894266fa5f641864280b4e
  Merge pull request #279 from 6by9/PR20160105
  Fixes for #34 and #142
- Git revision master 1d2a203de296150099cad9688818fa4fa8a208dc
  Raspistill: Ensure filename doesn't contain invalid % expansions
  https://github.com/raspberrypi/userland/issues/142
   Check that the output filename does not include %<char>
   other than %% or %d as it is fed into sprintf for adding
   the timelapse frame number.
- Git revision master 56963917df04dd9b67e951ac56774e1b64f1c4b6
  RaspiCamControl: State EV step size
  https://github.com/raspberrypi/userland/issues/34
   Step size is 1/6ths to support either 1/3rds or 1/2 steps.

* Fri Jan 01 2016 Clive Messer <clive.messer@squeezecommunity.org> - 20160101-501.git95cd3f6
- Git revision master 95cd3f6b1d00debf8ecb8303ec320384f9a401a8
  Merge pull request #277 from 6by9/PR20151230
  Various open issue fixes
- Git revision master 3c48a00f889e19f610f383f2ec7f4fe4126a0ff6
  Merge pull request #276 from 6by9/PR20151222
  MMAL Examples: Some fixups for the Pi tree
- Git revision master e0ecdb98a59a70048b64f8a5196d423680fbdc7e
  VCOS: Silence compiler warnings due to missing functions on pthreads
   Some functions defined as inline but not inlined.
   Some functions missing from the implementation.
   Shuts up a number of comiler warnings.
  https://github.com/raspberrypi/userland/issues/220
- Git revision master c34da352cb87bb5f5f486ca84608f450d4122c15
  Raspicam: Send help text to stdout
  All text was going to stderr as output data could be
   sent to stdout. Send help text to stdout so things
   like less will work.
  https://github.com/raspberrypi/userland/issues/244
- Git revision master f046bb4497083ba8d9e2247281014047d5e5d65e
  Raspicam: Remove RaspiCamDocs.odt as out of date
  https://github.com/raspberrypi/userland/issues/236
- Git revision master aaefc391ff2a440632f037a3a42ef2030d36d5b2
  Raspistill: Correct help text for DateTime (year not included)
  Year is not included in the filename as the 32 bit integer would
   overflow. Not updating to a 64bit int as the string format is
   passed in from the client, so would break compatibility.
  https://github.com/raspberrypi/userland/issues/274

* Thu Dec 31 2015 Clive Messer <clive.messer@squeezecommunity.org> - 20151231-501.git3c48a00
- Git revision master 3c48a00f889e19f610f383f2ec7f4fe4126a0ff6
  Merge pull request #276 from 6by9/PR20151222
  MMAL Examples: Some fixups for the Pi tree
- Git revision master 55f6f35bb59268f0b446d2c596eaa80e5cc2bbd2
  MMAL Examples: Some fixups for the Pi tree
  None of the examples linked against mmal_vc_client
   or bcm_host, so failed to find any VC components.
  https://github.com/raspberrypi/userland/issues/275

* Tue Dec 08 2015 Clive Messer <clive.messer@squeezecommunity.org> - 20151208-501.gitcfa3df1
- Git revision master cfa3df1420a1839eb4a1da12e744a4beb8e7e7b6
  video_decode: Provide ability to limit the number of callback structures used
   See: https://github.com/raspberrypi/firmware/issues/496
- Git revision master 9b55f905d124a789c0e57b81459a9c50b06e9435
  IL ISP component support
- Git revision master 2fe8df4a50b635202c0dbc36315686dca4e83f80
  video_encode: option to add timing data to SPS header
   See: https://github.com/raspberrypi/firmware/issues/245

* Tue Dec 01 2015 Clive Messer <clive.messer@squeezecommunity.org> - 20151201-501.git8d14732
- Git revision master 8d14732f45f2aa204fdec599c69a9bdab4583247
  Merge pull request #272 from sergioprado/master
  Fix error when building against musl libc.
- Git revision master 69eb69c25057ee724cc0c9e597df8c48bf1d852a
  Fix error when building against musl libc.
  When building with a musl based toolchain, the build fails with the
   following message:
  host_applications/linux/apps/raspicam/CMakeFiles/raspividyuv.dir/RaspiVidYUV.c.o
   In file included from
   error: conflicting type qualifiers for ‘stderr’
   extern FILE *stderr, *stdout;
   ^
  That's because musl defines stderr and stdout as a const pointer:
   extern FILE *const stdin;
   extern FILE *const stdout;
   extern FILE *const stderr;
  And the application (RaspiVidYUV.c) don't:
   extern FILE *stderr, *stdout;
  Since this declaration already comes in on the header (stdio.h),
   there is no need to add an extern declaration, so removes it to
   fix the build problem with the musl libc.
- Git revision master e3e5bd8f91d86d03e68ab1436032658a7d42e880
  Fix build: add missing headers

* Mon Nov 23 2015 Clive Messer <clive.messer@squeezecommunity.org> - 20151123-501.git8306b7c
- Git revision master 8306b7c757f4b8e8d9148789eeb64c666d9244a5
  audioserv: Bump peer version and allow setting of channelmap
- Git revision master 221ea0ffbe9f2b4feda237029389f22b59ba6127
  vchiq: Add missing vcos library dependency
- Git revision master bb0f52d5f4a3edc1fa3a0acca88c9c2f3073bc5e
  tv_service: Add missing return statement
- Git revision master f83d02d218cd3a8bb983f0a0e8b1c8f2cab97c8a
  vcos_assert: Swap order of message and bkpt for better gpu debugging
- Git revision master df52e0b0585622b405b5561e4f91adbe24707755
  camera: Allow loading of tuning data from a memory block
  Load tuning data from a relocatable heap memory block instead of
   via the file system.
- Git revision master 84d51749f7751e07175925975bee15c670f3a8d5
  vcilcs: Avoid a potential deadlock when very threaded
  Don't let the server thread block waiting for a response slot to become
   available, and increase the number of slots from 4 to 8.
  See: https://github.com/raspberrypi/firmware/issues/449

* Mon Nov 09 2015 Clive Messer <clive.messer@squeezecommunity.org> - 20151109-501.git888945b
- Git revision master 888945b683a4b8780adb3c217bd9a2a1a5899ef8
  Merge pull request #267 from fullergalway/master
  determine better whether annotation is a bitmask or string
- Git revision master 847c630993e44129766513f6049d8c92ac2c6879
  determine better whether annotation is a bitmask or string

* Wed Oct 28 2015 Clive Messer <clive.messer@squeezecommunity.org> - 20151028-501.git41f1c15
- Git revision master 41f1c15e74b913974c2a842871bf9e8dd9322ee3
  Merge pull request #264 from fullergalway/master
  allow annotation string to contain strftime parameters like %Y-%m-%d %X
- Git revision master 4494c80652dbd0cef3d73d2fa4114947cead79a7
  Allow strftime parameters for text annotation, but only if bitwise date or 
   time expansion requested and the string contains a '%'.
  Change also allows bitwise annotation together with text annotation.

* Thu Sep 24 2015 Clive Messer <clive.messer@squeezecommunity.org> - 20150924-501.git40e3778
- Git revision master 40e377862410371a9962db79b81fd4f0f266430a
  Merge pull request #258 from maxnet/master
  Proposing VC_DISPLAY env variable
- Git revision master 01d78356423f31092a9fe98d263d28e7c52a1a4c
  vc_dispmanx_display_open: allow display to be set with VC_DISPLAY env 
   variable
  Allow end-users to set the default display through a VC_DISPLAY 
   environement variable.
   E.g. to force hello_teapot to display on HDMI one could execute:
   VC_DISPLAY=5 ./hello_teapot.bin
  Signed-off-by: Floris Bos <bos@je-eigen-domein.nl>

* Sat Sep 12 2015 Clive Messer <clive.messer@squeezecommunity.org> - 20150912-501.gitcc92dfd
- Git revision master cc92dfd6c4e8e2d90c3903dccfe77f7274b8d1b7
  hello_video: Avoid hang on exit with some files
  See: https://www.raspberrypi.org/forums/viewtopic.php?f=38&t=79868
- Git revision master 2eb4db3575c416f64bf6fbae92d23405a69472b3
  tvserver: Make tvservice state report LCD state
- Git revision master fb11b39d97371c076eef7c85bbcab5733883a41e
  Merge pull request #248 from FIIT-TNL/master
  Added support for network and fflush to decrease latency.
- Git revision master d2b13260b3b93cd9d8a5d7491563863afd5f0911
  Added support for network and (optional) fflush to decrease latency.
- Git revision master 52ff85c622b088b4141e3f39c16a24374c947aa8
  Merge pull request #252 from asavah/glibc-2.22-fix
  Fix build with glibc 2.22
- Git revision master 34f02079dcb4602e86c578958eddf5ec072f85ea
  Fix build with glibc 2.22

* Thu Jul 09 2015 Clive Messer <clive.messer@squeezecommunity.org> - 20150709-501.gitb864a84
- Git revision master b864a841e5a459a66a890c22b3a34127cd226238
  vchiq: Better error handling
  Fix the user library to avoid a seg-fault on a duplicate service error,
   and ensure that errors in the errors in the vchiq_test functional test
   cause the test to stop.
- Git revision master ffdd891f144c99d2330f0b9d2a208fdf491b22bf
  khronos: merge with more recent header file
  See: https://github.com/raspberrypi/userland/issues/249

* Sat Jul 04 2015 Clive Messer <clive.messer@squeezecommunity.org> - 20150704-501.gitc2f27fb
- Git revision master c2f27fb8e581f8e5af83bf28422553ade8f7a7c8
  Merge pull request #171 from aizvorski/master
  Add exposure=off option
- Git revision master 57b0df9046bede16a90d2a9ef003b8bb8d49f339
  Early frame sequential 3d support

* Sun May 31 2015 Clive Messer <clive.messer@squeezecommunity.org> - 20150531-501.gitb834074
- Git revision master b834074d0c0d9d7e64c133ab14ed691999cee990
  mmal_queue: Add sanity checking to avoid common queue errors
- Git revision master d0954df802d43ea7cc94481435188913f6a65eee
  Add MMAL to IL mapping for rawcam parameters

* Tue May 26 2015 Clive Messer <clive.messer@squeezecommunity.org> - 20150526-502.gitd4aa617
- Remove the hard-coded provides.

* Tue May 26 2015 Clive Messer <clive.messer@squeezecommunity.org> - 20150526-501.gitd4aa617
- Git revision master d4aa617de3b196399bb8e2ce32e181768cb52179
   vcsm: Add ioctl for custom cache flushing

* Tue May 19 2015 Clive Messer <clive.messer@squeezecommunity.org> - 20150519-501.git9cc14b2
- Git revision master 9cc14b29288f913ef0e3286f4b3232bf73ab59d2
  vcsm: Update to header from kernel side

* Thu May 14 2015 Clive Messer <clive.messer@squeezecommunity.org> - 20150503-502.gitd280099
- Rebuild for F22.

* Sun May 03 2015 Clive Messer <clive.messer@squeezecommunity.org> - 20150503-501.gitd280099.sc20
- Git revision master d28009949fe97631373ae4e5ab9ba7ed61910ee7
  Merge pull request #241 from nubok/patch-1
  Added "all" target to hello_fft/makefile
- Git revision master 74a6acf296bd814760b4b33f31925087e2a55cc0
  Added "all" target to hello_fft/makefile    
  Same patch as https://github.com/raspberrypi/firmware/pull/422 for the 
   firmware repository: The reason, why I added a new target "all" is that 
   without it, the script /opt/vc/src/hello_pi/rebuild.sh only builds 
   hello_fft.bin, but not hello_fft_2d.bin.

* Wed Apr 29 2015 Clive Messer <clive.messer@squeezecommunity.org> - 20150429-501.gitd8f146a.sc20
- Git revision master d8f146af05c2b9cd92f9a426148376b349f744fd
  Merge pull request #240 from 6by9/master    
  Zero copy, and buildme change for Pi2
- Git revision master e8707f827c0e4ae5de892ac700b5bdb649350a1a
  Enable VCSM in MMAL by default
- Git revision master da7cab9fac646de891d84b232d1e25df1b6a0505
  Alter buildme to use multiple jobs and install on a Pi2

* Fri Apr 24 2015 Clive Messer <clive.messer@squeezecommunity.org> - 20150424-501.git198b9ac.sc20
- Git revision master 198b9ac3bcc0b54f1563664870fe415f04b7b6b5
  Merge pull request #239 from thaytan/master    
  Fix intra-refresh port parameter setting.
- Git revision master 41b2b2918f08fbf7603e6f52120fff5bb6cc802c
  Fix intra-refresh port parameter setting.    
  check mmal_port_parameter_get() succeeds when getting
   the default intra refresh values. It fails on older firmware.    
  Fixes #238

* Sat Apr 18 2015 Clive Messer <clive.messer@squeezecommunity.org> - 20150418gitb69f807-501.sc20
- Git revision master b69f807ce59189457662c2144a8e7e12dc776988
  Merge pull request #237 from MarkusMattinen/patch-1    
  Fix typo in buildme shebang
- Git revision master 36a20b6d92790a530421cb319a83ff9be79509d3
  Fix typo in buildme shebang    
  Fixes #176.

* Sun Apr 12 2015 Clive Messer <clive.messer@squeezecommunity.org> - 20150412gitb4f537b-501.sc20
- Git revision master b4f537beef05afbd4337b9ca309aaa8b984177be
  mmal: Pass dts in place of pts when pts is invalid
- Git revision master 3fda6f920d65e08e342eef51e2476313cd021410
  mmal: Plumb in OMX_IndexParamBrcmInterpolateMissingTimestamps

* Tue Mar 17 2015 Clive Messer <clive.messer@squeezecommunity.org> - 20150323git7650bcb-501.sc20
- Git revision master 7650bcbc9ba8f1c5e29be7726d184b31c2665c46
  Merge pull request #233 from jsonn/patch-1    
  Use a more sensible check than a tautoligy
- Git revision master 9b45a317b0ab56e83dfc228b6cd5800a0078835f
  Merge pull request #234 from jsonn/patch-2
  Fix typo in header guard
- Git revision master c08f005953a73dc9dc16df08d46d1baeb8c3bf4c
  Fix typo in header guard
- Git revision master 83b9970709e1f004542d0fccadbb7ea48b879d48
  Use a more sensible check than a tautoligy

* Tue Mar 17 2015 Clive Messer <clive.messer@squeezecommunity.org> - 20150317gitdaad93e-501.sc20
- Git revision master daad93e972f2332555ca2dc7b5a27a89d52572d5
  Merge pull request #225 from 6by9/PR20150223
  Raspistill/vid: More annotate options, and stereoscopic support.
- Git revision master d1a46714827d1192b86c0447c2c266ee5bb833be
  dispmanx: Add stereoscopic flags to control 3d duplication behaviour

* Tue Mar 10 2015 Clive Messer <clive.messer@squeezecommunity.org> - 20150310gitbb5b28f-501.sc20
- Git revision master bb5b28fc534f4f10c42c1c245673b26217aa03df
  Merge pull request #226 from 6by9/PR20150310
  Add an error message for MMAL_EVENT_ERROR
- Git revision master 695e11ced1e286d945f7dfcebae484ef3848a830
  Add an error message for MMAL_EVENT_ERROR    
  It is signalled by the camera when no data is received on the CSI-2
   bus. Handle it specifically to try and avoid a bundle of duplicate
   forum posts.
- Git revision master 0567cba5b7c4fe07cce4ed0f13b2abb846b29114
  tvservice: Add option to choose frame packed hdmi mode
- Git revision master a31c068cfbf3d79eca20e947a1eca39333be902d
  vchiq: Add version define to indicate synchronous support

* Mon Mar 09 2015 Clive Messer <clive.messer@squeezecommunity.org> - 20150309git041604e-501.sc20
- Git revision master 041604e47e73fb2a9a487ce6f446e9b2d2042546
  raspicam: Fix minor typo in RaspiTexUtil

* Sun Mar 08 2015 Clive Messer <clive.messer@squeezecommunity.org> - 20150308git2fa36bf-502.sc20
- Tidy-up raspberrypi-vc-demo-source-path-fixup.patch

* Sun Mar 08 2015 Clive Messer <clive.messer@squeezecommunity.org> - 20150308git2fa36bf-501.sc20
- Git revision master 2fa36bfebc63ed913f002dceca4e966b538ad879
  mmal: Add MVC as a video encoding
- Git revision master ee9e0e4a79f129ef6408041baeace9f79b8f4609
  firmware: hello_fft: Update to version 3
   See: http://www.aholme.co.uk/GPU_FFT/Main.htm

* Fri Feb 20 2015 Clive Messer <clive.messer@squeezecommunity.org> - 20150226git0de0b20-502.sc20
- Fix LICENCE file permissions.

* Fri Feb 20 2015 Clive Messer <clive.messer@squeezecommunity.org> - 20150226git0de0b20-501.sc20
- Git revision master 0de0b205ea94ab61c24ea515cd3935e37d41ac03.
  vdec3: preparation work for MVC.
- Git revision master 73b57a700702a0e85a4817fff1f5104f9119dc79
  Annotate: Add control of text size, colour, bg colour, and handle CR.
- Git revision master f309a963f9ed3a86805bb9f983d6f81e89041df7
  vcmailbox: Add utility app for driving mailbox interface from command line.

* Fri Feb 20 2015 Clive Messer <clive.messer@squeezecommunity.org> - 20150220git6f12209-501.sc20
- Git revision master 6f122099ca3ef1115c740f927a64ccf54ca576ba.
  tvservice: Clear 3d settings before switching to new hdmi mode.
- Git revision master 8efa5baddf63166b9d114ce34e1da10685a11ad6
  Annotate timelapse images with timestamp or datetime.

* Sat Feb 14 2015 Clive Messer <clive.messer@squeezecommunity.org> - 20150214gitc5341f0-501.sc20
- Git revision master c5341f09dc686c17966369485f7dd27f58dc081c.
  cmake: Add -fPIC to avoid linking issues with Pi2 compile flags.
- Drop -fPIC. (Upstream has added it to cmake flags.)
- Move raspberrypi-vc-firmware to standalone package.

* Thu Feb 12 2015 Clive Messer <clive.messer@squeezecommunity.org> - 20150212git47bd0f0-501.sc20
- Updated firmware to commit 47bd0f0f46bc053d8e21655e3a69c4a73ae19b41.
- Updated userland to commit ddf78b2975c9d2f7511a16ca46ba0dfacd627006.

* Wed Feb 11 2015 Clive Messer <clive.messer@squeezecommunity.org> - 20150207gitd10602a-502.sc20
- Build with -fPIC.

* Sat Feb 07 2015 Clive Messer <clive.messer@squeezecommunity.org> - 20150207gitd10602a-501.sc20
- Updated firmware to commit d10602a5f3f3788ed673d98e3dec2af25666365d.
- Updated userland to commit 3893680f941b79b839c3313378aacb3dd0fc60ab.

* Thu Feb 05 2015 Clive Messer <clive.messer@squeezecommunity.org> - 20150205git0dad7b9-501.rpfr20
- Updated firmware to commit 0dad7b957c549ec3ee6bd142dcce03db186d6979.

* Wed Feb 04 2015 Clive Messer <clive.messer@squeezecommunity.org> - 20150204git28f1f25-501.rpfr20
- Updated firmware to commit 28f1f25e26b33c243c833ff89b70eae5a3b2467c.

* Fri Jan 30 2015 Clive Messer <clive.messer@squeezecommunity.org> - 20150130git9b068fe-501.rpfr20
- Updated firmware to commit 9b068fe44503f564579a25fd849df4ec784f9d4d.
- Updated userland to commit 3b81b91c18ff19f97033e146a9f3262ca631f0e9.

* Tue Jan 27 2015 Clive Messer <clive.messer@squeezecommunity.org> - 20150127gitd7c798d-501.rpfr20
- Updated firmware to commit d7c798d33ac7bf9474fcbc6be235cd5988d258a7.
- Updated userland to commit 8f542a1647e6f88f254eadd9ad6929301c81913b.

* Wed Jan 21 2015 Clive Messer <clive.messer@squeezecommunity.org> - 20150123git90ed5e5-501.rpfr20
- Updated firmware to commit 90ed5e5a7338d5c9d7aaa3306f92aac51ad20cc7.

* Wed Jan 21 2015 Clive Messer <clive.messer@squeezecommunity.org> - 20150121git6efbc2e-501.rpfr20
- Updated firmware to commit 6efbc2e7811189ee497dc5d676819661031e11e3.
- Updated userland to commit 6f530690af1b6bfc0eab463a804be7bf24fb8d4a.

* Thu Dec 18 2014 Clive Messer <clive.messer@squeezecommunity.org> - 20141218git833534ca-501.rpfr20
- Updated firmware to commit 833534cacc4bd0ce1ed2c077bb42aa466c468536.
- Updated userland to commit fed4730aebc329187894e3d8c7aa1e2943a8fdc1.

* Thu Dec 11 2014 Clive Messer <clive.messer@squeezecommunity.org> - 20141211git5f1b910-501.rpfr20
- Updated firmware to commit 5f1b9100dd340125ebc8a96a8781d4497ea006f6
- Updated userland to commit 4333d6d023a1f0dcc763d0706a1fe6523f9b6005

* Tue Nov 25 2014 Clive Messer <clive.messer@squeezecommunity.org> - 20141125gitf56e48c-501.rpfr20
- Updated firmware to commit f56e48c00b30a985ed68306348fc493bf6050f6b

* Sat Nov 22 2014 Clive Messer <clive.messer@squeezecommunity.org> - 20141122git1513cf8-501.rpfr20
- Updated firmware to commit 1513cf89c1fa211e900c23fb4a8b4da73bfd7102

* Sun Nov 16 2014 Clive Messer <clive.messer@squeezecommunity.org> - 20141116gita54afb6-501.rpfr20
- Updated firmware to commit a54afb6fe333cd1ae72170d2a452ae94d428b9c7
- Updated userland to commit 4333d6d023a1f0dcc763d0706a1fe6523f9b6005

* Fri Oct 03 2014 Clive Messer <clive.messer@squeezecommunity.org> - 20141003gitf2275b9-502.rpfr20
- Add 'Provides: libcontainers.so'.
- Add 'Provides: libmmal_components.so'.

* Fri Oct 03 2014 Clive Messer <clive.messer@squeezecommunity.org> - 20141003gitf2275b9-501.rpfr20
- Updated firmware to latest commit f2275b92477d1a01f45f321d648f0eeeeeb0a67e
- Updated userland to latest commit 44c48e076d1a62180c82f490ac2c8d95b0eff2e7

* Sat Sep 13 2014 Clive Messer <clive.messer@squeezecommunity.org> - 20140913gitb465bdb-501.rpfr20
- Updated firmware to latest commit b465bdb633003339da911bc8df4be4552a46b26c
- Updated userland to latest commit 0cbcb3a67f39b0522e4413207481906595b3591b

* Tue Aug 26 2014 Clive Messer <clive.messer@squeezecommunity.org> - 20140826git6eda68a-501.rpfr20
- Updated firmware to latest commit 6eda68af0e3f0897c5b72a3d44003f16ecdc9110
- Updated userland to latest commit d9a999f1e08e7f5311102c4e5d2961685da38820

* Wed Aug 13 2014 Clive Messer <clive.messer@squeezecommunity.org> - 20140813git43c5b2f-501.rpfr20
- Updated firmware to latest commit 43c5b2fc9bdb0a43ba67661b8677445e71ae9e82
  kernel/libs: VCHIQ: Make service closure fully synchronous
   With these patches, calls to vchiq_close_service and vchiq_remove_service 
    won't return until any associated callback have been delivered to the 
    callback thread.  
  firmware: video_render: Add parameter for setting the colourspace
   Only applicable for non-opaque buffers.
  firmware: gpioman: Allow oscillator to be selected as a clock source
  firmware: image_decode: huffman and quantization tables shouldn't trigger 
   'keep all following'. 
   See: http://forum.stmlabs.com/showthread.php?tid=14839
  userland: hello_jpeg: Fix decode fail when width/height can't be parsed 
   from first 80K block.
  firmware: video_render: Fix for stereo rendering when crop height is not 
   populated.
* Sun Aug 10 2014 Clive Messer <clive.messer@squeezecommunity.org> - 20140810gitdf36e8d-501.rpfr20
- Add 'Provides: libvcsm.so' to libs sub-package.
- updated to firmware/userland to latest commit

* Wed Jul 02 2014 Andrew Greene <andrew.greene@senecacollege.ca> - 20140630git1682505-19.rpfr20
- updated to firmware/userland to latest commit

* Tue Jun 24 2014 Andrew Greene <andrew.greene@senecacollege.ca> - 20140618git462f3e3-18.rpfr20
- updated userland and firmware to latest commits

* Tue Jun 17 2014 Andrew Greene <andrew.greene@senecacollege.ca> - 20140616git5bb0317-17.rpfr20
- updated firmware to latest commit

* Fri Jun 13 2014 Andrew Greene <andrew.greene@senecacollege.ca> - 20140611gite45a4a2-16.rpfr20
- updated userland and firmware to latest commit

* Wed May 21 2014 Andrew Greene <andrew.greene@senecacollege.ca> - 20140516git97082b6-15.rpfr20
- Updated firmware and userland to latest commit also added missing commit date
  to userland

* Tue Apr 29 2014 Andrew Greene <andrew.greene@senecacollege.ca> - 20140428git316b922-14.rpfr20
- updated to latest commit

* Thu Apr 10 2014 Andrew Greene <andrew.greene@senecacollege.ca> - 20140117git940dc3b-13.rpfr20
- Added userland source files to build vc-demos from source

* Thu Mar 27 2014 Andrew Greene <andrew.greene@senecacollege.ca> - 20140117git940dc3b-12.rpfr20
- uncommented vc header patch

* Tue Jan 28 2014 Andrew Greene <andrew.greene@senecacollege.ca> - 20140117git940dc3b-8.rpfr20
- Added provides gl2.h to lib-devel

* Wed Jan 22 2014 Andrew Greene <andrew.greene@senecacollege.ca> - 20140117git940dc3b-7.rpfr20
- Initial build for pidora 2014 updated to latest commit

* Fri Nov 29 2013 Andrew Greene <andrew.greene@senecacollege.ca> - 20131128gitf7e9bcd-6.rpfr19
- updated to latest commit

* Mon Oct 28 2013 Andrew Greene <andrew.greene@senecacollege.ca> - 20131018git4c14569-5.rpfr18
- Updated to latest commit

* Thu Oct 17 2013 Andrew Greene <andrew.greene@senecacollege.ca> - 20131012git5113ce6-4.rpfr19
- Initial build for Pidora 19

* Wed Oct 16 2013 Andrew Greene <andrew.greene@senecacollege.ca> - 20131012git5113ce6-3.rpfr18
- Updated to latest commit

* Mon Sep 30 2013 Andrew Greene <andrew.greene@senecacollege.ca> - 20130918gitfadc4cb-2.rpfr18
- Added missing firmware files

* Thu Sep 19 2013 Andrew Greene <andrew.greene@senecacollege.ca> - 20130918gitfadc4cb-1.rpfr18
- Updated to latest commit

* Mon Sep 16 2013 Andrew Greene <andrew.greene@senecacollege.ca> - 20130910git7d8a762-1.rpfr18
- Updated to latest firmware

* Wed Aug 21 2013 andrew.greene@senecacollege.ca - 20130819git5b37b2a-1.rpfr18
- Updated to latest commit

* Fri Aug 16 2013 andrew.greene@senecacollege.ca - 20130815gite0590d6-1.rpfr18
- Updated to latest commit

* Mon Jul 15 2013 andrew.greene@senecacollege.ca - 20130711git245f716-3.rpfr18
- updated to latest commit moved header/lib files to subdirectory to deal with
  mesa lib conflicts and khrplatform conflicts

* Wed Jul 03 2013 andrew.greene@senecacollege.ca - 20130702gita36d33d-2.rpfr18
- moved conflicting headers to a sub dir and included a ld.so.conf.d file for
  conflicting libs

* Tue Jul 02 2013 andrew.greene@senecacollege.ca - 20130702gita36d33d-1.rpfr18
- Added provides for conflicts with mesa-libEGL-devel libs and updated firmware
  to latest commit

* Tue Jun 11 2013 andrew.greene@senecacollege.ca - 20130607git0d1b1d8-2.rpfr18
- updated to latest commit

* Wed May 15 2013 Chris Tyler <chris@tylers.info> - 20130415git1c339b1-1.rpfr18
- Updated to upstream, added suid on utils

* Fri Apr 19 2013 andrew.greene@senecacollege.ca - 20130410git7fcb9d3-2.rpfr18
- Included provides for libs libmmal_core and libmmal_util these are needed for vc-utils 

* Tue Apr 16 2013 andrew.greene@senecacollege.ca - 20130410git7fcb9d3eb2-1.rpfr18
- Updated to latest version changed vchost_config.h location

* Sat Mar 02 2013 andrew.greene@senecacollege.ca - 20121125git7e9ac50-7.rpfr18
- Copied missing header file to the correct location vchost_config.h vcos_platform_types.h and vcos_platform.h 

* Fri Mar 01 2013 andrew.greene@senecacollege.ca - 20121125git7e9ac50-4.rpfr18
- rebuilt for armv6hl

* Fri Mar 01 2013 andrew.greene@senecacollege.ca - 20121125git7e9ac50-3.rpfr18
- Added a provides tag

* Tue Nov 27 2012 Andrew Greene <andrew.greene@senecacollege.ca> - 20121125git7e9ac50-2.rpfr18
- Updated package release tag for rpfr18

* Tue Nov 27 2012 Chris Tyler <chris@tylers.info> - 20121125git7e9ac50-2.rpfr17
- Added provides for library subpackage
- Added softfp/hardfp binary selection

* Sun Nov 25 2012 Chris Tyler <chris@tylers.info> - 20121125git7e9ac50-1.rpfr17
- Updated to upstream

* Wed Sep 26 2012 Chris Tyler <chris@tylers.info> - 20120926gitb87bc42-1.rpfr17
- Updated to upstream

* Mon Aug 13 2012 Chris Tyler <chris@tylers.info> - 20120813gitcb9513f-1.rpfr17
- Updated to upstream
- Merged raspberrypi-firmware (now named raspberrypi-vc-firmware)

* Wed Aug 08 2012 Chris Tyler <chris@tylers.info> - 20120727git0d88fba-1.rpfr17
- Updated to upstream

* Wed Jul 04 2012 Chris Tyler <chris@tylers.info> - 20120703git0671d60-2.rpfr17
- Path and patch fixups

* Wed Jul 04 2012 Chris Tyler <chris@tylers.info> - 20120703git0671d60-1.rpfr17
- Updated to current upstream, adjusted for git commit in version

* Mon Mar 05 2012 Chris Tyler <chris@tylers.info> - 20120217-4
- Added path fixup for demo source code

* Mon Mar 05 2012 Chris Tyler <chris@tylers.info> - 20120217-3
- Fixed up move from vc/ subdir in /usr/include.

* Mon Mar 05 2012 Chris Tyler <chris@tylers.info> - 20120217-2
- Removed strip on libilclient.a, moved ilclient.h

* Tue Feb 21 2012 - Chris Tyler <chris.tyler@senecacollege.ca> - 20120217-1
- Initial packaging
